@@ -57,8 +57,10 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.List;
+import java.util.Map;
+import javax.net.ssl.SSLContext;
+import javax.net.ssl.SSLSocketFactory;
 import javax.ws.rs.core.Response.Status;
-import javax.xml.ws.WebServiceException;
 import org.apache.commons.fileupload.MultipartStream;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
@@ -68,6 +70,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.imageconverter.api.IImageClient;
@@ -76,6 +79,7 @@ import com.openexchange.imageconverter.api.IMetadataReader;
 import com.openexchange.imageconverter.api.ImageConverterException;
 import com.openexchange.imageconverter.api.MetadataImage;
 import com.openexchange.imageconverter.client.generated.invoker.ApiException;
+import com.openexchange.imageconverter.client.generated.invoker.ApiResponse;
 import com.openexchange.imageconverter.client.generated.modules.ImageConverterApi;
 
 /**
@@ -104,7 +108,11 @@ public class ImageConverterClient implements IImageClient {
      * @param imageConverterClientConfig
      * @throws OXException
      */
-    public ImageConverterClient(@NonNull final ConfigurationService configurationService) throws OXException {
+    public ImageConverterClient(
+        @NonNull final ConfigurationService configurationService,
+        @NonNull final SSLContext sslContext,
+        @NonNull final SSLSocketFactory sslSocketFactory) throws OXException {
+
         super();
 
         m_clientConfig = new ImageConverterClientConfig(configurationService);
@@ -113,7 +121,7 @@ public class ImageConverterClient implements IImageClient {
         	throw OXException.general("Configuration service is available, but config property is not valid");
         }
 
-        m_apiProvider = new ImageConverterApiProvider(m_clientConfig);
+        m_apiProvider = new ImageConverterApiProvider(m_clientConfig, sslSocketFactory, sslContext);
         m_remoteValidator = new ImageConverterRemoteValidator(m_clientConfig, m_apiProvider);
     }
 
@@ -132,7 +140,7 @@ public class ImageConverterClient implements IImageClient {
     public InputStream getImage(final String imageKey, final String requestFormat, final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
         InputStream ret = null;
-        
+
         LOG.trace("IC client #getImage called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
 
         if (null != api) {
@@ -176,9 +184,11 @@ public class ImageConverterClient implements IImageClient {
                     File tmpResponseFile = null;
 
                     try {
-                        if (null != (tmpResponseFile = api.getMetadata(imageKey, implGetContext(context)))) {
+                        final ApiResponse<File> fileResponse = api.getMetadataWithHttpInfo(imageKey, implGetContext(context));
+
+                        if ((null != fileResponse) && (null != (tmpResponseFile = fileResponse.getData()))) {
                             try (final InputStream fileInputStm = FileUtils.openInputStream(tmpResponseFile);
-                                 final MetadataImage metadataImage = implCreateMetadataImage(api, fileInputStm)) {
+                                 final MetadataImage metadataImage = implCreateMetadataImage(fileInputStm, fileResponse.getHeaders())) {
 
                                 if (null != metadataImage) {
                                     ret = metadataImage.getMetadata();
@@ -217,9 +227,11 @@ public class ImageConverterClient implements IImageClient {
                     File tmpResponseFile = null;
 
                     try {
-                        if (null != (tmpResponseFile = api.getImageAndMetadata(imageKey, requestFormat, implGetContext(context)))) {
+                        final ApiResponse<File> fileResponse = api.getImageAndMetadataWithHttpInfo(imageKey, requestFormat, implGetContext(context));
+
+                        if ((null != fileResponse) && (null != (tmpResponseFile = fileResponse.getData()))) {
                             try (final InputStream fileInputStm = FileUtils.openInputStream(tmpResponseFile)) {
-                                ret = implCreateMetadataImage(api, fileInputStm);
+                                ret = implCreateMetadataImage(fileInputStm, fileResponse.getHeaders());
                             }
                         }
                     } catch (ApiException e) {
@@ -336,9 +348,11 @@ public class ImageConverterClient implements IImageClient {
                             File tmpResponseFile = null;
 
                             try {
-                                if (null != (tmpResponseFile = api.cacheAndGetImageAndMetadata(imageKey, requestFormat, tmpInputFile, implGetContext(context)))) {
+                                final ApiResponse<File> fileResponse = api.cacheAndGetImageAndMetadataWithHttpInfo(imageKey, requestFormat, tmpInputFile, implGetContext(context));
+
+                                if ((null != fileResponse) && (null != (tmpResponseFile = fileResponse.getData()))) {
                                     try (final InputStream fileInputStm = FileUtils.openInputStream(tmpResponseFile)) {
-                                        ret = implCreateMetadataImage(api, fileInputStm);
+                                        ret = implCreateMetadataImage(fileInputStm, fileResponse.getHeaders());
                                     }
                                 }
                             } catch (ApiException e) {
@@ -459,9 +473,8 @@ public class ImageConverterClient implements IImageClient {
         return 0;
     }
 
-    /**
-     * @return
-     * @throws WebServiceException
+    /* (non-Javadoc)
+     * @see com.openexchange.imageconverter.api.IImageClient#status()
      */
     @Override
     public String status() throws OXException {
@@ -472,7 +485,7 @@ public class ImageConverterClient implements IImageClient {
 
         if (null != api) {
             try {
-                ret = api.status();
+                ret = api.status("false");
             } catch (ApiException e) {
                 ImageConverterException ice = implWrapAPIException("Error in remote calling ImageConverter#status", e);
                 if (ice != null) {
@@ -511,7 +524,7 @@ public class ImageConverterClient implements IImageClient {
     		throw ice;
     	}
     }
-    
+
     private ImageConverterException implWrapAPIException(final String msg, final ApiException e) {
         final StringBuilder throwMessageBuilder = new StringBuilder(StringUtils.isNotEmpty(msg) ? msg : "IC client received unknown API exception");
         boolean throwException = true;
@@ -541,7 +554,7 @@ public class ImageConverterClient implements IImageClient {
         if (throwException) {
             return new ImageConverterException(throwMessageBuilder.toString());
         }
-        
+
         return null;
     }
 
@@ -584,12 +597,16 @@ public class ImageConverterClient implements IImageClient {
     /**
      * @param metadataImageMultipartFile
      */
-    private static MetadataImage implCreateMetadataImage(@NonNull final ImageConverterApi api, @NonNull final InputStream metadataImageMultipartInputStm) throws IOException, IndexOutOfBoundsException {
-        final String contentType = api.getApiClient().getResponseHeaders().get( "Content-Type").get(0);
+    private static MetadataImage implCreateMetadataImage(
+        @NonNull final InputStream metadataImageMultipartInputStm,
+        @Nullable final Map<String, List<String>> headers) throws IOException, IndexOutOfBoundsException {
+
+        final List<String> contentTypeHeaderList = (null != headers) ? headers.get("Content-Type") : null;
+        final String contentType = ((null != contentTypeHeaderList) && !contentTypeHeaderList.isEmpty()) ? contentTypeHeaderList.get(0) : null;
         int boundaryStartPos = -1;
         MetadataImage ret = null;
 
-        if (isNotEmpty(contentType) && contentType.startsWith("multipart/") &&
+        if ((null != contentType) && contentType.startsWith("multipart/") &&
             ((boundaryStartPos = contentType.lastIndexOf("boundary")) > -1)) {
 
             final String boundary = (contentType.substring(boundaryStartPos).split("="))[1].trim();
@@ -599,13 +616,13 @@ public class ImageConverterClient implements IImageClient {
 
             if (multipartStream.skipPreamble()) {
                 do {
-                    final String headers = multipartStream.readHeaders();
+                    final String partHeaders = multipartStream.readHeaders();
 
                     try (final ByteArrayOutputStream bodyOutputStm = new ByteArrayOutputStream()) {
                         if (multipartStream.readBodyData(bodyOutputStm) > 0) {
-                            if (headers.contains("application/octet-stream")) {
+                            if (partHeaders.contains("application/octet-stream")) {
                                 imageInputStm = new ByteArrayInputStream(bodyOutputStm.toByteArray());
-                            } else if (headers.contains("application/json")) {
+                            } else if (partHeaders.contains("application/json")) {
                                 final IMetadataReader metadataReader = Services.optService(IMetadataReader.class);
 
                                 if (null != metadataReader) {
