@@ -67,8 +67,6 @@ import com.openexchange.config.ConfigurationService;
  */
 public final class ImageConverterClientConfig {
 
-    final private static File DEFAULT_TEMP_DIR = new File("/tmp");
-
     final private static String REMOTE_TEST_URL = "file:///ImageConverterClient_TestURL";
 
     final private static String IMAGECONVERTER_CLIENT_TEMP_DIRNAME = "oxiccli";
@@ -96,7 +94,7 @@ public final class ImageConverterClientConfig {
      *
      */
     public void shutdown() {
-        if (m_terminated.compareAndSet(false, true)) {
+        if (m_running.compareAndSet(true, false)) {
             FileUtils.deleteQuietly(m_spoolDir);
         }
     }
@@ -134,7 +132,7 @@ public final class ImageConverterClientConfig {
      * @return
      */
     public File getSpoolDir() {
-        return (!m_terminated.get() ? m_spoolDir : DEFAULT_TEMP_DIR);
+        return (m_running.get() ? m_spoolDir : FileUtils.getTempDirectory());
     }
 
     // - Implementation --------------------------------------------------------
@@ -182,7 +180,7 @@ public final class ImageConverterClientConfig {
 
     // - Members ---------------------------------------------------------------
 
-    final private AtomicBoolean m_terminated = new AtomicBoolean(false);
+    final private AtomicBoolean m_running = new AtomicBoolean(true);
 
     private ConfigurationService m_configurationService = null;
 
