@@ -128,7 +128,7 @@ class ImageConverterRemoteValidator {
 
             if (null != imageConverterApi) {
                 try {
-                    if (isNotEmpty(statusResponse = imageConverterApi.status())) {
+                    if (isNotEmpty(statusResponse = imageConverterApi.status("false"))) {
                         statusResponse = statusResponse.toLowerCase();
 
                         try (final BufferedReader stringReader = new BufferedReader(new StringReader(statusResponse))) {
@@ -182,7 +182,7 @@ class ImageConverterRemoteValidator {
                 }
 
                 m_remoteAPIVersion.set(remoteApiVersion);
-                m_isRunning.compareAndSet(true, false);
+                m_running.compareAndSet(true, false);
             }
 
             return Integer.valueOf(remoteApiVersion);
@@ -240,7 +240,7 @@ class ImageConverterRemoteValidator {
      * @return
      */
     synchronized int getRemoteAPIVersion() {
-        if (isRemoteServerSupported() && (m_remoteAPIVersion.get() < 1) && m_isRunning.compareAndSet(false, true)) {
+        if (isRemoteServerSupported() && (m_remoteAPIVersion.get() < 1) && m_running.compareAndSet(false, true)) {
             m_executorService.submit(new FutureTask<>(m_callable));
         }
 
@@ -251,7 +251,7 @@ class ImageConverterRemoteValidator {
      *
      */
     synchronized void resetConnection() {
-        if ((null != m_callable) && (m_remoteAPIVersion.get() >= 1) && !m_isRunning.get()) {
+        if ((null != m_callable) && (m_remoteAPIVersion.get() >= 1) && !m_running.get()) {
             implSetConnectionLost();
         }
     }
@@ -301,7 +301,7 @@ class ImageConverterRemoteValidator {
 
     final protected ExecutorService m_executorService = Executors.newCachedThreadPool();
 
-    final protected AtomicBoolean m_isRunning = new AtomicBoolean(false);
+    final protected AtomicBoolean m_running = new AtomicBoolean(false);
 
     final protected AtomicInteger m_remoteAPIVersion = new AtomicInteger(-1);
 
